@@ -1,4 +1,4 @@
-/* $Id: gucharmap-search-dialog.c 1300 2007-01-19 18:32:05Z chpe $ */
+/* $Id: gucharmap-search-dialog.c 1331 2007-04-26 12:56:08Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -39,6 +39,7 @@ enum
 };
 
 static guint gucharmap_search_dialog_signals[NUM_SIGNALS] = { 0, 0 };
+static GObjectClass *parent_class;
 
 enum
 {
@@ -821,6 +822,8 @@ gucharmap_search_dialog_finalize (GObject *object)
 
   if (priv->search_state)
     gucharmap_search_state_free (priv->search_state);
+
+  parent_class->finalize (object);
 }
 
 static void
@@ -828,6 +831,8 @@ gucharmap_search_dialog_class_init (GucharmapSearchDialogClass *clazz)
 {
   g_type_class_add_private (clazz, sizeof (GucharmapSearchDialogPrivate));
 
+  parent_class = (GObjectClass *) g_type_class_peek_parent (clazz);
+
   G_OBJECT_CLASS (clazz)->finalize = gucharmap_search_dialog_finalize;
 
   clazz->search_start = NULL;
